"""
testcases for cssutils.CSSSerializer
"""
__version__ = '0.9a6'

import basetest

import cssutils


class CSSSerializerTestCase(basetest.BaseTestCase):
    """
    testcases for cssutils.CSSSerializer
    """
##    def test_init(self):
##        "CSSSerializer.__init__()"


    def _resetprefs(self):
        cssutils.ser.prefs = cssutils.serialize.Preferences()

    def test_indent(self):
        "CSSSerializer Preferences.ident"
        s = cssutils.parseString('a { left: 0 }')
        exp4 = '''a {
    left: 0
    }'''
        exp1 = '''a {
 left: 0
 }'''
        self.assertEqual(exp4, s.cssText)
        cssutils.ser.prefs.indent = ' '
        self.assertEqual(exp1, s.cssText)
        cssutils.ser.prefs.indent = '    '
        self.assertEqual(exp4, s.cssText)

        self._resetprefs()


    def test_linenumbers(self):
        "CSSSerializer Preferences.linenumbers"
        s = cssutils.parseString('a {top: 1; left: 2}')
        exp0 = '''a {
    top: 1;
    left: 2
    }'''
        exp1 = '''1: a {
2:     top: 1;
3:     left: 2
4:     }'''
        self.assertEqual(False, cssutils.ser.prefs.linenumbers)
        self.assertEqual(exp0, s.cssText)
        cssutils.ser.prefs.linenumbers = True
        self.assertEqual(True, cssutils.ser.prefs.linenumbers)
        self.assertEqual(exp1, s.cssText)

        self._resetprefs()


    def test_keepcomments(self):
        "CSSSerializer Preferences.keepcomments"
        s = cssutils.parseString('/*1*/ a { /*2*/ }')
        cssutils.ser.prefs.keepcomments = False
        self.assertEqual('a {}', s.cssText)

        self._resetprefs()


    def test_srcatkeyword(self):
        "CSSSerializer Preferences.srcatkeyword"
        s = cssutils.parseString('@im\port "x";')
        self.assertEqual('@import "x";', s.cssText)
        cssutils.ser.prefs.srcatkeyword = True
        self.assertEqual('@im\port "x";', s.cssText)

        self._resetprefs()


    def test_CSSImportRule(self):
        "CSSSerializer 'CSSImportrule.href format'"
        r0 = cssutils.css.CSSImportRule(u'not')
        r1 = cssutils.css.CSSImportRule(u'str', hreftype="string")
        r2 = cssutils.css.CSSImportRule(u'uri', hreftype="uri")
        self.assertEqual('@import url(not);', r0.cssText)
        self.assertEqual('@import "str";', r1.cssText)
        self.assertEqual('@import url(uri);', r2.cssText)

        cssutils.ser.prefs.importHrefFormat = 'string'
        self.assertEqual('@import "not";', r0.cssText)
        self.assertEqual('@import "str";', r1.cssText)
        self.assertEqual('@import "uri";', r2.cssText)

        cssutils.ser.prefs.importHrefFormat = 'uri'
        self.assertEqual('@import url(not);', r0.cssText)
        self.assertEqual('@import url(str);', r1.cssText)
        self.assertEqual('@import url(uri);', r2.cssText)

        cssutils.ser.prefs.importHrefFormat = 'not defined' 
        self.assertEqual('@import url(not);', r0.cssText)
        self.assertEqual('@import "str";', r1.cssText)
        self.assertEqual('@import url(uri);', r2.cssText)
        
        self._resetprefs()


if __name__ == '__main__':
    import unittest
    unittest.main()